RUNDEF Section01
       SELECTION ALL

/*
COUNTING SELECTED INDIVIDUALS OF A HOUSEHOLD

Program description:
A household variable is derived by counting the number of persons
entity PERSON) complying with a given criteria. 
In the example, the program counts the number of head of the household
(PERSON.RELAT=1).
A simple frequency of the variable displays the results.

Note:
This program also checks the consistency of the database. 
There should be one person and only one person declared as head of household. 
*/ 

DEFINE HOUSIN.NHEADS AS COUNT PERSON
  FOR PERSON.RELAT = 1
  TYPE INTEGER

TABLE VERIF AS FREQUENCY OF HOUSIN.NHEADS

/*
Programming Notes:
1. In the RUNDEF command, the clause SELECTION ALL can be ommited
   since it is ALL by default.
2. In the DEFINE command, the clause TYPE INTEGER can also be ommited,
   since TYPE INTEGER is the default.
3. The commands could have been written in a single line, such as (it is
   just a matter of programming style):
   rundef Section01 selection all define HOUSIN.NHEADS as count PERSON for PERSON.RELAT=1 type integer table t1 as frequency of HOUSIN.NHEADS 
4. Although we recommend to separate the commands (RUNDEF, DEFINE and TABLE)
   in different lines 
5. As you already might have guessed, you can use lower or capital letters
   in all the programming clauses, BUT entity and variable names MUST be written
   the same way they are defined in the dictionary.
   So, PERSON.RELAT is not the same as person.relat, or PERSON.relat.
6. There must be at least one blank space separating a clause from a command.
7. Blanks might be ommited in the logical (or arithmetic) expressions. 
   PERSON.RELAT = 1
   is the same as
   PERSON.RELAT=1
8. Comments can placed be anywhere in a program.
   They are written as a block, starting with /star and finishing
   with star/ like this one here
   (in your comments, substitute the word "star" as stated here by a *)
   or in a single line starting with a double slash (//), such as
   //this is a comment       

Results:
	Categories  Counts
	0            2544
	1           11375
	Total       13919

Comments:
1. There are no households with more than one head. 
2. However, there are households with no heads, which could mean that
   they are collective households, empty households, or another
   condition that we will leave open for the time being. 
*/
           